.. _gaia-install:

============
Installation
============

Dependencies
============

* numpy
* astropy >= 3.0
* pandas

With ``pip``
============

To install the latest stable version using ``pip``, use::

    pip install pyia

To install the development version::

    pip install git+https://github.com/adrn/pyia

Cloning, Building, Installing
=============================

The latest development version of gala can be cloned from
`GitHub <https://github.com/>`_ using ``git``::

   git clone git://github.com/adrn/pyia.git

To build the project (from the root of the source tree, e.g., inside
the cloned ``gaia`` directory)::

    python setup.py build

To install the project::

    python setup.py install
